EXPORTS
	E32Dll__F10TDllReason @ 1 NONAME R3UNUSED ; E32Dll(TDllReason)
	NewLC__23CPAppPresenceConnection @ 2 NONAME R3UNUSED ; CPAppPresenceConnection::NewLC(void)
	NewL__23CPAppPresenceConnection @ 3 NONAME R3UNUSED ; CPAppPresenceConnection::NewL(void)
	"_._23CPAppPresenceConnection" @ 4 NONAME R3UNUSED ; CPAppPresenceConnection::~CPAppPresenceConnection(void)
	"_._25CPAppPresenceConnectionUi" @ 5 NONAME R3UNUSED ; CPAppPresenceConnectionUi::~CPAppPresenceConnectionUi(void)
	LoggedInL__25CPAppPresenceConnectionUi21TPAppConnectionClient @ 6 NONAME R3UNUSED ; CPAppPresenceConnectionUi::LoggedInL(TPAppConnectionClient)
	PureServiceStatusL__25CPAppPresenceConnectionUi @ 7 NONAME R3UNUSED ; CPAppPresenceConnectionUi::PureServiceStatusL(void)
	LoginL__25CPAppPresenceConnectionUi21TPAppConnectionClient14TPAppLoginTypeP24MPAppConnProcessObserver @ 8 NONAME ; CPAppPresenceConnectionUi::LoginL(TPAppConnectionClient, TPAppLoginType, MPAppConnProcessObserver *)
	LogoutL__25CPAppPresenceConnectionUi21TPAppConnectionClientP24MPAppConnProcessObserver @ 9 NONAME R3UNUSED ; CPAppPresenceConnectionUi::LogoutL(TPAppConnectionClient, MPAppConnProcessObserver *)
	NewLC__25CPAppPresenceConnectionUiP19CWVSAPSettingsStore @ 10 NONAME R3UNUSED ; CPAppPresenceConnectionUi::NewLC(CWVSAPSettingsStore *)
	NewL__25CPAppPresenceConnectionUiP19CWVSAPSettingsStore @ 11 NONAME R3UNUSED ; CPAppPresenceConnectionUi::NewL(CWVSAPSettingsStore *)
	HandleSapAccessEventEventL__24MPAppConnProcessObserverRC7TDesC16T1P18MPAppConnProcessUi @ 12 NONAME ; MPAppConnProcessObserver::HandleSapAccessEventEventL(TDesC16 const &, TDesC16 const &, MPAppConnProcessUi *)
	ReservedObservMethod_3L__24MPAppConnProcessObserver @ 13 NONAME R3UNUSED ; MPAppConnProcessObserver::ReservedObservMethod_3L(void)
	ReservedObservMethod_1L__24MPAppConnProcessObserver @ 14 NONAME R3UNUSED ; MPAppConnProcessObserver::ReservedObservMethod_1L(void)
	ReservedObservMethod_2L__24MPAppConnProcessObserver @ 15 NONAME R3UNUSED ; MPAppConnProcessObserver::ReservedObservMethod_2L(void)
	"_._40CPAppConnUiClntFilteredPresEventNotifier" @ 16 NONAME R3UNUSED ; CPAppConnUiClntFilteredPresEventNotifier::~CPAppConnUiClntFilteredPresEventNotifier(void)
	AppServiceStatusL__28CPAppConnUiPresEventNotifier @ 17 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::AppServiceStatusL(void)
	GetLoggedInSapL__25CPAppPresenceConnectionUiR14CWVSAPSettings @ 18 NONAME R3UNUSED ; CPAppPresenceConnectionUi::GetLoggedInSapL(CWVSAPSettings &)
	HandleApplicationExitL__25CPAppPresenceConnectionUi21TPAppConnectionClient13TPAppExitTypeP24MPAppConnProcessObserver @ 19 NONAME ; CPAppPresenceConnectionUi::HandleApplicationExitL(TPAppConnectionClient, TPAppExitType, MPAppConnProcessObserver *)
	LoggedInL__25CPAppPresenceAAConnection21TPAppConnectionClient @ 20 NONAME R3UNUSED ; CPAppPresenceAAConnection::LoggedInL(TPAppConnectionClient)
	LoginL__25CPAppPresenceAAConnection21TPAppConnectionClienti @ 21 NONAME R3UNUSED ; CPAppPresenceAAConnection::LoginL(TPAppConnectionClient, int)
	NewLC__25CPAppPresenceAAConnectionP19CWVSAPSettingsStore @ 22 NONAME R3UNUSED ; CPAppPresenceAAConnection::NewLC(CWVSAPSettingsStore *)
	NewLC__28CPAppConnUiPresEventNotifier @ 23 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::NewLC(void)
	NewLC__40CPAppConnUiClntFilteredPresEventNotifier21TPAppConnectionClient @ 24 NONAME R3UNUSED ; CPAppConnUiClntFilteredPresEventNotifier::NewLC(TPAppConnectionClient)
	NewL__25CPAppPresenceAAConnectionP19CWVSAPSettingsStore @ 25 NONAME R3UNUSED ; CPAppPresenceAAConnection::NewL(CWVSAPSettingsStore *)
	NewL__28CPAppConnUiPresEventNotifier @ 26 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::NewL(void)
	NewL__40CPAppConnUiClntFilteredPresEventNotifier21TPAppConnectionClient @ 27 NONAME R3UNUSED ; CPAppConnUiClntFilteredPresEventNotifier::NewL(TPAppConnectionClient)
	PureServiceStatusL__25CPAppPresenceAAConnection @ 28 NONAME R3UNUSED ; CPAppPresenceAAConnection::PureServiceStatusL(void)
	RemoveObserver__28CPAppConnUiPresEventNotifierP32MPAppConnUiPresenceEventObserver @ 29 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::RemoveObserver(MPAppConnUiPresenceEventObserver *)
	StartL__28CPAppConnUiPresEventNotifier @ 30 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::StartL(void)
	Stop__28CPAppConnUiPresEventNotifier @ 31 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::Stop(void)
	"_._25CPAppPresenceAAConnection" @ 32 NONAME R3UNUSED ; CPAppPresenceAAConnection::~CPAppPresenceAAConnection(void)
	"_._28CPAppConnUiPresEventNotifier" @ 33 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::~CPAppConnUiPresEventNotifier(void)
	AddObserverL__28CPAppConnUiPresEventNotifierP32MPAppConnUiPresenceEventObserver @ 34 NONAME R3UNUSED ; CPAppConnUiPresEventNotifier::AddObserverL(MPAppConnUiPresenceEventObserver *)
	NewLC__33CPAppConnUiConnectionModeNotifier21TPAppConnectionClient @ 35 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::NewLC(TPAppConnectionClient)
	NewL__33CPAppConnUiConnectionModeNotifier21TPAppConnectionClient @ 36 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::NewL(TPAppConnectionClient)
	AddObserverL__33CPAppConnUiConnectionModeNotifierP33MPAppConnUiConnectionModeObserver @ 37 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::AddObserverL(MPAppConnUiConnectionModeObserver *)
	RemoveObserver__33CPAppConnUiConnectionModeNotifierP33MPAppConnUiConnectionModeObserver @ 38 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::RemoveObserver(MPAppConnUiConnectionModeObserver *)
	ConnectionModeL__33CPAppConnUiConnectionModeNotifier @ 39 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::ConnectionModeL(void)
	StartL__33CPAppConnUiConnectionModeNotifier @ 40 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::StartL(void)
	Stop__33CPAppConnUiConnectionModeNotifier @ 41 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::Stop(void)
	DisconnectAllL__25CPAppPresenceConnectionUi21TPAppConnectionClientP24MPAppConnProcessObserver @ 42 NONAME R3UNUSED ; CPAppPresenceConnectionUi::DisconnectAllL(TPAppConnectionClient, MPAppConnProcessObserver *)
	LogoutL__25CPAppPresenceAAConnection21TPAppConnectionClienti @ 43 NONAME R3UNUSED ; CPAppPresenceAAConnection::LogoutL(TPAppConnectionClient, int)
	"_._33CPAppConnUiConnectionModeNotifier" @ 44 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::~CPAppConnUiConnectionModeNotifier(void)
	ConnectionModeByCategoryL__33CPAppConnUiConnectionModeNotifier24TPAppConnectionModeEvent @ 45 NONAME R3UNUSED ; CPAppConnUiConnectionModeNotifier::ConnectionModeByCategoryL(TPAppConnectionModeEvent)
	NewL__22CPAppConnectionUiAgent21TPAppConnectionClient @ 46 NONAME R3UNUSED ; CPAppConnectionUiAgent::NewL(TPAppConnectionClient)
	StartServiceL__22CPAppConnectionUiAgent29TPAppConnectionUiAgentService @ 47 NONAME R3UNUSED ; CPAppConnectionUiAgent::StartServiceL(TPAppConnectionUiAgentService)
	StopAllServices__22CPAppConnectionUiAgent @ 48 NONAME R3UNUSED ; CPAppConnectionUiAgent::StopAllServices(void)
	StopService__22CPAppConnectionUiAgent29TPAppConnectionUiAgentService @ 49 NONAME R3UNUSED ; CPAppConnectionUiAgent::StopService(TPAppConnectionUiAgentService)
	"_._22CPAppConnectionUiAgent" @ 50 NONAME R3UNUSED ; CPAppConnectionUiAgent::~CPAppConnectionUiAgent(void)
	AddObserverL__37CPAppConnUiConnectionSettingsNotifierP37MPAppConnUiConnectionSettingsObserver @ 51 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::AddObserverL(MPAppConnUiConnectionSettingsObserver *)
	ConnectionSettingByCategoryL__37CPAppConnUiConnectionSettingsNotifier28TPAppConnectionSettingsEvent @ 52 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::ConnectionSettingByCategoryL(TPAppConnectionSettingsEvent)
	NewLC__37CPAppConnUiConnectionSettingsNotifier21TPAppConnectionClient @ 53 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::NewLC(TPAppConnectionClient)
	NewL__37CPAppConnUiConnectionSettingsNotifier21TPAppConnectionClient @ 54 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::NewL(TPAppConnectionClient)
	RemoveObserver__37CPAppConnUiConnectionSettingsNotifierP37MPAppConnUiConnectionSettingsObserver @ 55 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::RemoveObserver(MPAppConnUiConnectionSettingsObserver *)
	StartL__37CPAppConnUiConnectionSettingsNotifier @ 56 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::StartL(void)
	Stop__37CPAppConnUiConnectionSettingsNotifier @ 57 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::Stop(void)
	"_._37CPAppConnUiConnectionSettingsNotifier" @ 58 NONAME R3UNUSED ; CPAppConnUiConnectionSettingsNotifier::~CPAppConnUiConnectionSettingsNotifier(void)
	CurrentConnectionOperationL__25CPAppPresenceConnectionUiRP7HBufC16 @ 59 NONAME R3UNUSED ; CPAppPresenceConnectionUi::CurrentConnectionOperationL(HBufC16 *&)	
	ValidWVLoginIAPL__32PAppPresenceLoginDetailValidatorUl @ 60 NONAME R3UNUSED ; PAppPresenceLoginDetailValidator::ValidWVLoginIAPL(unsigned long)
	ValidWVLoginIdL__32PAppPresenceLoginDetailValidatorRC7TDesC16 @ 61 NONAME R3UNUSED ; PAppPresenceLoginDetailValidator::ValidWVLoginIdL(TDesC16 const &)
	DefaultServerNameL__25CPAppPresenceAAConnection @ 62 NONAME R3UNUSED ; CPAppPresenceAAConnection::DefaultServerNameL(void)
	UseResourceFileL__22CPAppConnectionUiAgentRC7TDesC16 @ 63 NONAME R3UNUSED ; CPAppConnectionUiAgent::UseResourceFileL(TDesC16 const &)

